%global libmajor 23
%define libname  %mklibname isl %{libmajor}
%define devname  %mklibname isl -d

Summary:        Integer point manipulation library
Name:           isl
Version:        0.24
Release:        %mkrel 2
License:        MIT
Group:          System/Libraries
URL:            https://repo.or.cz/isl.git
Source0:        https://gcc.gnu.org/pub/gcc/infrastructure/isl-%{version}.tar.bz2
# without this patch the distro RPM_OPT_FLAGS aren't used, and thus the debugsource would result empty
Patch0:         isl-0.24-fix-empty-debugsource.patch
# from debian
Patch1:         python3-compat.patch
#
# from git at https://repo.or.cz/isl.git
Patch101:       0001-plain_cpp_generator-impl_printer-print_save_ctx-don-.patch
Patch102:       0002-impl_printer-print_exceptional_execution_check-don-t.patch
Patch103:       0003-configure.ac-avoid-bash-specific-comparison.patch
#
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig
BuildRequires:  gcc >= 5.2.1

%description
isl is a library for manipulating sets and relations of integer points
bounded by linear constraints.  Supported operations on sets include
intersection, union, set difference, emptiness check, convex hull,
(integer) affine hull, integer projection, computing the lexicographic
minimum using parametric integer programming, coalescing and parametric
vertex enumeration.  It also includes an ILP solver based on generalized
basis reduction, transitive closures on maps (which may encode infinite
graphs), dependence analysis and bounds on piecewise step-polynomials.

%package -n %{libname}
Summary:        Integer point manipulation library
Group:          System/Libraries
Requires:       isl >= %{version}-%{release}

%description -n %{libname}
isl is a library for manipulating sets and relations of integer points
bounded by linear constraints.  Supported operations on sets include
intersection, union, set difference, emptiness check, convex hull,
(integer) affine hull, integer projection, computing the lexicographic
minimum using parametric integer programming, coalescing and parametric
vertex enumeration.  It also includes an ILP solver based on generalized
basis reduction, transitive closures on maps (which may encode infinite
graphs), dependence analysis and bounds on piecewise step-polynomials.

%package -n %{devname}
Summary:        Development for building integer point manipulation library
Group:          Development/Other
Requires:       isl >= %{version}-%{release}
Requires:       %{libname} >= %{version}-%{release}
Requires:       gmp-devel
%rename   isl-devel

%description -n %{devname}
isl is a library for manipulating sets and relations of integer points
bounded by linear constraints.  Supported operations on sets include
intersection, union, set difference, emptiness check, convex hull,
(integer) affine hull, integer projection, computing the lexicographic
minimum using parametric integer programming, coalescing and parametric
vertex enumeration.  It also includes an ILP solver based on generalized
basis reduction, transitive closures on maps (which may encode infinite
graphs), dependence analysis and bounds on piecewise step-polynomials.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure
%make_build

%install
%make_install INSTALL="install -p"

rm -f %{buildroot}%{_libdir}/libisl.a
rm -f %{buildroot}%{_libdir}/libisl.la

mkdir -p %{buildroot}%{_datadir}
%global gdbprettydir %{_datadir}/gdb/auto-load/%{_libdir}
mkdir -p %{buildroot}%{gdbprettydir}
mv %{buildroot}%{_libdir}/*-gdb.py* %{buildroot}%{gdbprettydir}

%check
make check

%files -n %{libname}
%{_libdir}/libisl.so.%{libmajor}{,.*}

%files
%doc AUTHORS ChangeLog LICENSE README
%{gdbprettydir}/*

%files -n %{devname}
%doc doc/manual.pdf
%{_includedir}/*
%{_libdir}/libisl.so
%{_libdir}/pkgconfig/isl.pc


%changelog
* Mon Mar 21 2022 umeabot <umeabot> 0.24-2.mga9
+ Revision: 1816647
- Mageia 9 Mass Rebuild

* Sun Mar 13 2022 ghibo <ghibo> 0.24-1.mga9
+ Revision: 1790842
- Update to release 0.24.
- Bump major release to 23.
- Drop Patch0.
- Add patch to use distro CFLAGS and avoid empty debubsource.
- Add patch python3-compat from debian.
- Fix URL.
- Fix Source0 URL.
- Merge patches from git repo (200 and beyond).

* Wed Feb 26 2020 daviddavid <daviddavid> 0.18-2.mga8
+ Revision: 1550765
- add patch to port libisl-gdb.py to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Jan 22 2019 luigiwalser <luigiwalser> 0.18-1.mga7
+ Revision: 1359157
- 0.18

* Sun Sep 23 2018 umeabot <umeabot> 0.16.1-2.mga7
+ Revision: 1298332
- Mageia 7 Mass Rebuild

* Sun Jan 24 2016 luigiwalser <luigiwalser> 0.16.1-1.mga6
+ Revision: 926999
- update to 0.16.1 (lib major 15)

* Sun Jan 24 2016 luigiwalser <luigiwalser> 0.14-3.mga6
+ Revision: 926979
- revert to 0.14 temporarily to properly libify
- 0.16.1 (compatible with 0.15)

* Sun Jan 24 2016 luigiwalser <luigiwalser> 0.15-1.mga6
+ Revision: 926932
- 0.15
- library major is now 15
- use configure2_5x to fix build

* Thu Aug 20 2015 tmb <tmb> 0.14-2.mga6
+ Revision: 867004
- rebuild with new gcc

* Wed Aug 19 2015 tmb <tmb> 0.14-1.mga6
+ Revision: 866010
- fix devel group
- clean spec
- imported package isl


* Mon Jan 5 2015 David Howells <dhowells@redhat.com> - 0.14-3
- Initial packaging.
